Changelog
=========

0.0.2 (2025-02-03)
------------------

- added methods `parse_rgb` and `parse_rgba`
- added class `ColorProvider` to make color management easier


0.0.1 (2025-02-03)
------------------

- initial release
